@@ -1,5 +1,33 @@
 #!/usr/bin/env python3
 
+
+'''
+    Project home: github.com/zebpalmer/WeatherAlerts
+    Original Author: Zeb Palmer   (www.zebpalmer.com)
+    For more info, please see the README.rst
+
+    This program is free software you can redistribute it and
+    or modify it under the terms of the GNU General Public License
+    as published by the Free Software Foundation, either version
+    3 of the License, or (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+
+'''
+
+
+
+
+
+
+
 import sys
 from weatheralerts import nws
 
@@ -35,4 +63,4 @@ if __name__ == "__main__":
 
         print(result)
     else:
-        print("No arguments supplied, please see the wiki")
\ No newline at end of file
+        print("No arguments supplied, please see the wiki")
