@@ -1,31 +1,52 @@
 #!/usr/bin/env python3
 
 '''
-    Project home: git.zebpalmer.com/nws-alerts
-    Original Author: Zeb Palmer   (www.zebpalmer.com)
-    For more info, please see the README.rst
+WeatherAlerts.nws
+*******************
 
-    This program is free software you can redistribute it and
-    or modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation, either version
-    3 of the License, or (at your option) any later version.
+File Information
+==================
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+**Project Home:**
+  http://github.com/zebpalmer/WeatherAlerts
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+**Original Author:**
+  Zeb Palmer http://www.zebpalmer.com
 
 
+**Documentation:**
+  http://weatheralerts.readthedocs.org
+
+
+**License:**
+  GPLv3 - full text included in LICENSE.txt
+
+
+License Notice:
+"""""""""""""""""
+This program is free software you can redistribute it and or modify it under the terms of the GNU General Public
+License as published by the Free Software Foundation, either version 3 of the License, or (at your option)
+any later version. This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+See the GNU General Public License for more details.  You should have received a copy of the GNU General Public
+License along with this program. If not, see <http://www.gnu.org/licenses/>.
+
+
+Code Documentation
+===================
+
 '''
 
 
+
 import os
 import sys
 import re
-from urllib import request
+try:
+    from urllib import request
+except:
+    from urllib import urlopen as request
+    print("You are trying to run the python3 version in python2, this won't go well")
 from xml.dom import minidom
 from datetime import datetime, timedelta
 import pickle as pickle
@@ -35,8 +56,7 @@ import json
 
 
 class GeoDB(object):
-    '''Class to interact with samecodes object and (soon) other geo data
-    TODO: move interaction with samecodes data to here'''
+    '''Interact with samecodes object and other geolocation data that will be added soon'''
     def __init__(self):
         self.__same = SameCodes()
         self.samecodes = self.__same.samecodes
@@ -45,6 +65,7 @@ class GeoDB(object):
     def location_lookup(self, req_location):
         '''
         returns full location given samecode or county and state. Returns False if not valid.
+        *currently locations are a dictionary, once other geo data is added, they will move to a location class/obj*
         '''
         location = False
         locations = self.samecodes
@@ -60,25 +81,23 @@ class GeoDB(object):
 
 
     def lookup_samecode(self, local, state):
-        '''return same code given county, state'''
+        '''Given County, State return the SAME code for specified location. Return False if not found'''
         for location in self.samecodes:
             if state == self.samecodes[location]['state']:
                 if local == self.samecodes[location]['local']:
                     return self.samecodes[location]
-
         return False
 
     def getstate(self, geosame):
-        '''Return the state of a given SAME code'''
+        '''Given a SAME code, return the state that SAME code is in'''
         state = self.samecodes[geosame]['state']
         return state
 
 
     def getfeedscope(self, geocodes):
-        '''Given multiple SAME codes, this determines if they are all in one state if so, it returns that state.
-           Otherwise it returns 'US'. This is used to determine which NWS feed needs to be parsed to get
-           all alerts for the given SAME codes'''
-
+        '''Given multiple SAME codes, determine if they are all in one state. If so, it returns that state.
+           Otherwise return 'US'. This is used to determine which NWS feed needs to be parsed to get
+           all alerts for the requested SAME codes'''
         states = self.get_states_from_samecodes(geocodes)
         if len(states) >= 2:
             return 'US'
@@ -87,7 +106,10 @@ class GeoDB(object):
 
 
     def get_states_from_samecodes(self, geocodes):
-        '''Returns all states for a given list of SAME codes'''
+        '''Returns all states for a given list of SAME codes
+        *Shouldn't be used to determine feed scope, please use getfeedscope()*
+
+        '''
         states = []
         for code in geocodes:
             try:
@@ -107,7 +129,10 @@ class GeoDB(object):
 #### GET/PARSE SAME CODES TABLE ##############################################################
 
 class SameCodes(object):
-    '''Download and parse samecodes database into an object, cache it'''
+    '''
+    Is used to download, parse and cache the SAME codes data from the web.
+    *All interaction with the SAME codes data should be done in the GeoGB classy*
+    '''
     def __init__(self):
         self._cachedir = str(tempfile.gettempdir()) + '/'
         self._same_cache_file = self._cachedir + 'nws_samecodes.cache'
@@ -168,7 +193,7 @@ class SameCodes(object):
             if file_ts > maxage:
                 try:
                     cache = open(cache_file, 'rb')
-                    self.samecodes = pickle.load(cache)
+                    self._samecodes = pickle.load(cache)
                     cache.close()
                     #print "Loaded SAME codes from Cache"
                     return True
@@ -189,21 +214,26 @@ class CapAlertsFeed(object):
     '''Class to fetch and load the NWS CAP/XML Alerts feed for the US or a single state if requested
        if an instance of the SameCodes class has already been (to do a geo lookup), you can pass that
        as well to save some processing'''
-    def __init__(self, state='US', geo=None):
+    def __init__(self, state='US', geo=None, maxage=3, reload=False):
         self._alerts = ''
         self._feedstatus = ''
-        self.state = self.set_state(state, refresh=False)
+        self._cachetime = maxage
+        self.state = self._set_state(state, refresh=False)
         self._cachedir = str(tempfile.gettempdir()) + '/'
         self._alert_cache_file = self._cachedir + 'nws_alerts_%s.cache' % (self.state)
         if geo == None:
             self.geo = GeoDB()
         else:
             self.geo = geo
-            
         self.samecodes = self.geo.samecodes
+
         self._cachetime = 3
         self._alerts_ts = datetime.now()
+        self._lookuptable = {}
+        self._reload = reload
+        # now for the real work
         self._load_alerts()
+        
 
 
     @property
@@ -212,12 +242,8 @@ class CapAlertsFeed(object):
         self.check_objectage()
         return self._alerts
 
-    def set_maxage(self, maxage=3):
-        '''Override the default max age for the alerts cache'''
-        self._cachetime = maxage
 
-
-    def set_state(self, state, refresh=True):
+    def _set_state(self, state, refresh=True):
         '''sets state, reloads alerts unless told otherwise'''
         if len(state) == 2:
             self.state = state.upper()
@@ -286,7 +312,7 @@ class CapAlertsFeed(object):
         return xml
 
     def _parse_cap(self, xmlstr):
-        '''parse the feed contents'''
+        '''parse and cache the feed contents'''
         main_dom = minidom.parseString(xmlstr)
 
         xml_entries = main_dom.getElementsByTagName('entry')
@@ -317,6 +343,7 @@ class CapAlertsFeed(object):
                 except IndexError:
                     return {}
             entry['type'] = pat.match(entry['title']).group(1)
+            
             locations = []
             for geo in entry['geocodes']:
                 try:
@@ -326,6 +353,11 @@ class CapAlertsFeed(object):
                                  'local': geo,
                                  'state': 'unknown'}
                 locations.append(location)
+
+                # We're going to create a table to reference alerts by
+                # TODO: make all alert lookups use the resulting data 
+                self._create_lookuptable(geo, entry_num, entry['type'])
+
             target_areas = []
             areas = str(entry['cap:areaDesc']).split(';')
             for area in areas:
@@ -334,14 +366,22 @@ class CapAlertsFeed(object):
             entry['target_areas'] = target_areas
             alerts[entry_num] = entry
             del entry
+        # cache alerts data
         cache = open(self._alert_cache_file, 'wb')
         pickle.dump(alerts, cache)
         cache.close()
         self._alerts_ts = datetime.now()
         return alerts
 
-
-
+    def _create_lookuptable(self, samecode, alert_num, alert_type):
+        alert_tuple = (alert_num, alert_type)
+        if samecode in self._lookuptable:
+            self._lookuptable[samecode].append(alert_tuple)
+        else:
+            _alertids = []
+            _alertids.append(alert_tuple)
+            self._lookuptable[samecode] = _alertids
+    
 
 class FormatAlerts(object):
     def __init__(self):
@@ -417,7 +457,7 @@ class Alerts(object):
 
         if load == True:
             self.load_alerts()
-            
+
 
     def load_alerts(self):
         '''manually load the cap feed/alerts'''
@@ -459,10 +499,10 @@ class Alerts(object):
         '''returns python object of all alerts for specified feed(National by default)'''
         if self.geocodes:
             alerts = self.cap.alerts
-            
+
         alerts = self.cap.alerts
         jsonobj = self.output.jsonout(alerts)
-        
+
 
     def national_summary(self):
         cap = CapAlertsFeed(state='US')
@@ -530,17 +570,17 @@ class Alerts(object):
                     location_alerts.append(alert_data[alert])
         return location_alerts
 
-    @property
-    def active_locations(self, alert_data):
-        '''returns list of all active locations'''
-        warned_areas = {}
-        for alert in alert_data.keys():
-            for location in alert_data[alert]['locations']:
-                if location['code'] not in list(warned_areas.keys()):
-                    warned_areas[location['code']] = [alert]
-                else:
-                    warned_areas[location['code']].append(alert)
-        return warned_areas
+    #@property
+    #def active_locations(self, alert_data):
+        #'''returns list of all active locations'''
+        #warned_areas = {}
+        #for alert in alert_data.keys():
+            #for location in alert_data[alert]['locations']:
+                #if location['code'] not in list(warned_areas.keys()):
+                    #warned_areas[location['code']] = [alert]
+                #else:
+                    #warned_areas[location['code']].append(alert)
+        #return warned_areas
 
 
 def alert_type(alert):
@@ -558,11 +598,5 @@ def alert_type(alert):
 
 
 
-
-
-
-
-
-
 if __name__ == "__main__":
-    pass
\ No newline at end of file
+    nws_alerts = Alerts(state='ID')
